@@ -557,16 +557,49 @@ vapply(files, function(file) paste0(readLines(file), "\n", collapse = ""), "")
     if (length(args) == 0L)
         as.list(Sys.getenv())
     else {
+        visible <- FALSE
         if (length(args) == 1L &&
             typeof(args[[1L]]) %in% c("NULL", "pairlist", "language",
                 "...", "list", "expression") &&
             is.null(names(args)))
         {
             args <- args[[1L]]
+            if (typeof(args) == "...") {
+                # ... <- args
+                assign("...", args)
+                args <- list(...)
+            }
+            else if (!is.vector(args) || is.object(args))
+                args <- as.list(args)
         }
-        value <- as.list(Sys.getenv(names(args), names = TRUE))
-        do.call("Sys.setenv", args, quote = TRUE)
-        invisible(value)
+        if (!length(args))
+            value <- structure(list(), names = character())
+        else if (is.null(tags <- names(args)) ||
+                 all(i <- tags == ""))
+        {
+            visible <- TRUE
+            tags <- vapply(args, .AS_SCALAR_STR, "", USE.NAMES = FALSE)
+            value <- as.list(Sys.getenv(tags, unset = NA, names = TRUE))
+        }
+        else {
+            if (any(i)) {
+                visible <- TRUE
+                tags[i] <- vapply(args[i], .AS_SCALAR_STR, "", USE.NAMES = FALSE)
+                args <- args[!i]
+            }
+            value <- as.list(Sys.getenv(tags, unset = NA, names = TRUE))
+            args <- lapply(args, .AS_SCALAR_STR)
+            na <- vapply(args, identical, NA_character_, FUN.VALUE = NA, USE.NAMES = FALSE)
+            if (any(na)) {
+                Sys.unsetenv(names(args)[na])
+                args <- args[!na]
+            }
+            if (length(args))
+                do.call("Sys.setenv", args, quote = TRUE)
+        }
+        if (visible)
+            value
+        else invisible(value)
     }
 }
 
@@ -591,6 +624,32 @@ vapply(files, function(file) paste0(readLines(file), "\n", collapse = ""), "")
 .External2(.C_IS_SCALAR_STR, x)
 
 
+.AS_SCALAR_STR <- function (x)
+{
+    switch (typeof(x),
+    `NULL` = NA_character_,
+    logical = ,
+    integer = ,
+    double = ,
+    complex = ,
+    character = ,
+    raw = {
+        if (is.object(x))
+            x <- unclass(x)
+        if (length(x))
+            as.character(x[[1L]])
+        else NA_character_
+    },
+    char = as.character(list(x)),
+    symbol = as.character(x),
+    NA_character_)
+}
+
+
+.AS_SCALAR_STR <- function (x)
+.External2(.C_AS_SCALAR_STR, x)
+
+
 .scalar_streql <- function (e1, e2)
 .External2(.C_scalar_streql, e1, e2)
 
